@@ -1,14 +1,16 @@
-from ..interfaces.ivalidator import IValidator
 from inspect import Signature, signature
-from typing import List, Any, Type, Callable
+from typing import Any, Callable, List, Type
+
+from ..interfaces.ivalidator import IValidator
+
 
 class PrimitiveDependencyValidator(IValidator):
     def is_valid(self, interface: Type, implementation: Any) -> bool:
         implementation_type: Type = type(implementation)
-        if(implementation_type == type(type)):
+        if implementation_type == type(type):
             # Not a Concrete implementation - therefore cannot have primitive
-            return not self.has_primitive_dependency(value= implementation)
-        elif implementation_type == type(lambda: ''):
+            return not self.has_primitive_dependency(value=implementation)
+        elif implementation_type == type(lambda: ""):
             return True
         else:
             return True
@@ -21,11 +23,5 @@ class PrimitiveDependencyValidator(IValidator):
         return False
 
     def is_primitive(self, value: Type) -> bool:
-        primitive_types: List[Type] = [
-            int,
-            str,
-            bool,
-            float,
-            complex
-        ]
-        return primitive_types.__contains__(value)
\ No newline at end of file
+        primitive_types: List[Type] = [int, str, bool, float, complex]
+        return primitive_types.__contains__(value)
